[llvm-commits] CVS: llvm/include/llvm/Function.h GlobalValue.h GlobalVariable.h

Reid Spencer reid at x10sys.com
Tue Jan 30 12:10:04 PST 2007



Changes in directory llvm/include/llvm:

Function.h updated: 1.70 -> 1.71
GlobalValue.h updated: 1.31 -> 1.32
GlobalVariable.h updated: 1.38 -> 1.39
---
Log message:

For PR1136: http://llvm.org/PR1136 : Rename GlobalVariable::isExternal as isDeclaration to avoid
confusion with external linkage types.


---
Diffs of the changes:  (+12 -13)

 Function.h       |    8 ++++----
 GlobalValue.h    |    6 +++---
 GlobalVariable.h |   11 +++++------
 3 files changed, 12 insertions(+), 13 deletions(-)


Index: llvm/include/llvm/Function.h
diff -u llvm/include/llvm/Function.h:1.70 llvm/include/llvm/Function.h:1.71
--- llvm/include/llvm/Function.h:1.70	Fri Jan 26 02:01:30 2007
+++ llvm/include/llvm/Function.h	Tue Jan 30 14:08:38 2007
@@ -89,11 +89,11 @@
   /// arguments.
   bool isVarArg() const;
 
-  /// isExternal - Is the body of this function unknown? (The basic block list
-  /// is empty if so.) This is true for external functions, defined as forward
-  /// "declare"ations
+  /// isDeclaration - Is the body of this function unknown? (The basic block 
+  /// list is empty if so.) This is true for function declarations, but not 
+  /// true for function definitions.
   ///
-  virtual bool isExternal() const { return BasicBlocks.empty(); }
+  virtual bool isDeclaration() const { return BasicBlocks.empty(); }
 
   /// getIntrinsicID - This method returns the ID number of the specified
   /// function, or Intrinsic::not_intrinsic if the function is not an


Index: llvm/include/llvm/GlobalValue.h
diff -u llvm/include/llvm/GlobalValue.h:1.31 llvm/include/llvm/GlobalValue.h:1.32
--- llvm/include/llvm/GlobalValue.h:1.31	Fri Jan 26 22:42:50 2007
+++ llvm/include/llvm/GlobalValue.h	Tue Jan 30 14:08:38 2007
@@ -113,9 +113,9 @@
   /// Override from Constant class.
   virtual void destroyConstant();
 
-  /// isExternal - Return true if the primary definition of this global value is
-  /// outside of the current translation unit...
-  virtual bool isExternal() const = 0;
+  /// isDeclaration - Return true if the primary definition of this global 
+  /// value is outside of the current translation unit...
+  virtual bool isDeclaration() const = 0;
 
   /// getParent - Get the module that this global value is contained inside
   /// of...


Index: llvm/include/llvm/GlobalVariable.h
diff -u llvm/include/llvm/GlobalVariable.h:1.38 llvm/include/llvm/GlobalVariable.h:1.39
--- llvm/include/llvm/GlobalVariable.h:1.38	Sat Dec 16 23:15:12 2006
+++ llvm/include/llvm/GlobalVariable.h	Tue Jan 30 14:08:38 2007
@@ -58,17 +58,16 @@
                  Constant *Initializer, const std::string &Name,
                  GlobalVariable *InsertBefore);
   
-  /// isExternal - Is this global variable lacking an initializer?  If so, the
-  /// global variable is defined in some other translation unit, and is thus
-  /// externally defined here.
-  ///
-  virtual bool isExternal() const { return getNumOperands() == 0; }
+  /// isDeclaration - Is this global variable lacking an initializer?  If so, 
+  /// the global variable is defined in some other translation unit, and is thus
+  /// only a declaration here.
+  virtual bool isDeclaration() const { return getNumOperands() == 0; }
 
   /// hasInitializer - Unless a global variable isExternal(), it has an
   /// initializer.  The initializer for the global variable/constant is held by
   /// Initializer if an initializer is specified.
   ///
-  inline bool hasInitializer() const { return !isExternal(); }
+  inline bool hasInitializer() const { return !isDeclaration(); }
 
   /// getInitializer - Return the initializer for this global variable.  It is
   /// illegal to call this method if the global is external, because we cannot






More information about the llvm-commits mailing list